Get Involved! | Security Lab
Author: Your Name
Description: ServiceNow wants to help interested security researchers better understand our products and platform technologies.
Date: 2016-03-23T08:48:41-07:00

# Get Involved!

Laid out below are some select resources that can accelerate learning about our platform technologies for both new and seasoned users, with an eye toward security.

## Securing Applications

Security is critical for keeping applications and their data safe from unauthorized viewing or use.

Course

## Secure Apps and Data

Security protects applications and data from unauthorized access.

Article

## Scripted REST APIs: Resource Security...

Information about security facets of the scripted REST APIs.

Article

## ServiceNow Security Best Practices Guide

Key considerations for securing your Now Platform® instance.

PDF

## ServiceNow Shared Responsibility Model

Security is a shared responsibility between both the customer and ServiceNow. Therefore, it is essential that each party understands their role in this partnership.

PDF

Enter your search term...